/*
 * This is a Groovy macro for RTextDoc that import some important info aabout current documen.
 *
 * Global variables include:
 *   - rtext:           The focused application window, an instance of
 *                      org.fife.rtext.RText.
 *   - textArea:        The active text area, an instance of
 *                      org.fife.rtext.RTextEditorPane.
 */
import org.fife.rtext.*;


// RTextDoc part
// Original file name without path
doc_name=jehep.ui.SetEnv.getEditorName()
// file name with full path
doc_fullname=jehep.ui.SetEnv.getEditorNameFull()
// File name without ".tex"
doc_basename =jehep.ui.SetEnv.getEditorNameBase()
// directory of the file
doc_path=jehep.ui.SetEnv.getEditorFilePath()

// OS
osname = System.getProperty( "os.name" ).toLowerCase();
scriptDir = jehep.ui.SetEnv.getInstallDir()
 
isWindows=false
rsep="; " // command separator 
lsep="\n" // linux separator 

if (osname.substring(0,3).equals("win")) { 
  isWindows=true
  rsep=" & "
  lsep=" : "
  evaluate(new File(scriptDir+File.separator+"macros"+File.separator+"common"+File.separator+"windows.groovy"))
} else if (osname.substring(0,3).equals("nux") || osname.substring(0,3).equals("lin") ) {
  evaluate(new File(scriptDir+File.separator+"macros"+File.separator+"common"+File.separator+"linux.groovy"))
} else if (osname.substring(0,3).equals("mac")) { 
  evaluate(new File(scriptDir+File.separator+"macros"+File.separator+"common"+File.separator+"mac.groovy"))
}


// exit if not PDF
if (!jehep.ui.SetEnv.checkEditorNameExtension("tex")) return;


// get autodetected commands
commands=jehep.ui.SetEnv.getCommands()
latex=commands[0][1]
bibtex=commands[1][1]
dvips=commands[2][1]
pdflatex=commands[3][1]
makeindex=commands[4][1]
ps2pdf=commands[5][1]
dvipdfm=commands[6][1]
viewer=commands[7][1]


// LaTeX autodetected command  
if (latex.length()>1) {
   // do not stop when error
   latex= "\""+latex+ "\" -interaction nonstopmode -file-line-error-style "+ doc_basename; // autodetected command  
   // latex= "\""+latex+"\" -file-line-error-style -halt-on-error -interaction errorstopmode " +  doc_basename;
} else {
   latex=latexString.replace("|", doc_basename) // custom command 
}

  
// pdfLaTeX autodetected command  
if (pdflatex.length()>1) {
   // do not stop
   pdflatex= "\""+pdflatex+"\" -interaction nonstopmode -file-line-error-style "+ doc_basename; // autodetected command  
   // pdflatex= "\""+pdflatex+"\" -file-line-error-style -halt-on-error -interaction errorstopmode " +  doc_basename;
} else {
   pdflatex=pdflatexString.replace("|", doc_basename) // custom command 
}

// BibTeX autodetected command  
if (bibtex.length()>1) {
   bibtex= "\""+bibtex + "\" "+ doc_basename; // autodetected command  
} else {
   bibtex=bibtexString.replace("|", doc_basename) // custom command 
}

// DVIPS autodetected command  
if (dvips.length()>1) {
   dvips= "\""+dvips + "\" -o "+ doc_basename +".ps "+doc_basename; // autodetected command  
} else {
   dvips=dvipsString.replace("|", doc_basename) // custom command 
}

// PS2PDF autodetected command  
if (ps2pdf.length()>1) {
   ps2pdf= "\""+ps2pdf + "\" -dMaxSubsetPct=100 -dSubsetFonts=true -dEmbedAllFonts=true -dPDFSETTINGS=/printer -dCompatibilityLevel=1.4 "+ doc_basename +".ps "+doc_basename+".pdf"; // autodetected command  
} else {
   ps2pdf=ps2pdfString.replace("|", doc_basename) // custom command 
}


// DVIPDF autodetected command  
if (dvipdfm.length()>1) {
   dvipdfm= "\""+dvipdfm + "\" -o "+ doc_basename +".pdf "+doc_basename; // autodetected command  
} else {
   dvipdfm=dvipdfmString.replace("|", doc_basename) // custom command 
}


// PDF Viewer  
if (viewer.length()>1) {
   viewer= "\""+viewer + "\" "+ doc_basename+".pdf"; // autodetected command  
} else {
   viewer=acroreadString.replace("|",doc_basename)
}

