#!/bin/bash
# RTextDoc launch file for Linux/Mac
# assume this script in this directory

export RTEXTDOC_HOME="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"


arguments="$@"


if which java >/dev/null; then
    _java=java
elif [[ -n "$JAVA_HOME" ]] && [[ -x "$JAVA_HOME/bin/java" ]];  then
    _java="$JAVA_HOME/bin/java"
else
    echo "No java detected! Please install it from https://java.com/download"; exit 0
fi

################## do not edit ###############################
JAVA_HEAP_SIZE=2048
CLASSPATH=$RTEXTDOC_HOME:$CLASSPATH

for i in $RTEXTDOC_HOME/*.jar
do
      CLASSPATH="$i":$CLASSPATH
done


# Add in your .jar files first
for i in $RTEXTDOC_HOME/lib/*.jar
do
      CLASSPATH="$i":$CLASSPATH
done

for i in $RTEXTDOC_HOME/lib/*/*.jar
do
      CLASSPATH="$i":$CLASSPATH
done

for i in $RTEXTDOC_HOME/lib/*/*/*.jar
do
      CLASSPATH="$i":$CLASSPATH
done

LIBJEHEP=$RTEXTDOC_HOME"/native/linux-i586/"
OS=`uname`
arch=`uname -m`


if [ "$OS" = "Darwin" ]; then
  echo "Running on Mac.."
  LIBJEHEP=$RTEXTDOC_HOME"/native/macosx/"
fi

if [ "$OS" == "Linux" ]; then
if  [ $arch = i386 ]; then
            LIBJEHEP=$RTEXTDOC_HOME"/native/linux-i586/"
            echo "Running on Linux i386 .."
     elif [ $arch = "i486" ]; then
            LIBJEHEP=$RTEXTDOC_HOME"/native/linux-i586/"
            echo "Running on Linux i486 .."
     elif [ $arch = "i586" ]; then
            LIBJEHEP=$RTEXTDOC_HOME"/native/linux-i586/"
            echo "Running on Linux i586 .."          
     elif [ $arch = "i686" ]; then
            LIBJEHEP=$RTEXTDOC_HOME"/native/linux-i586/"
            echo "Running on Linux i686 .."
     elif [ $arch = "x86_64" ]; then
            LIBJEHEP=$RTEXTDOC_HOME"/native/linux-amd64/"
            echo "Running on Linux x86_64 .."
     else
        echo "Unsupported Architecture"
fi
fi

# some computers may run 32 bit java even on 64 bit
if [ $arch = "x86_64" ]; then
  java -d64 -version > /tmp/log_rtextdoc 2>&1
  javacheck=`cat /tmp/log_rtextdoc`
  if `echo ${javacheck} | grep "not supported" 1>/dev/null 2>&1`
  then
    LIBJEHEP=$RTEXTDOC_HOME"/lib/linux-i586/"
    echo "Running a 32-bit JVM "
  else
    echo "Running a 64-bit JVM " 
fi
fi

export PATH=$LIBJEHEP:$PATH


OPTJJ="-Djava.library.path=$LIBJEHEP"
$_java -mx${JAVA_HEAP_SIZE}m -cp $CLASSPATH $OPTJJ -Dpython.home=${JYTHON_HOME} -Djehep.home=${RTEXTDOC_HOME} org.fife.rtext.RText ${arguments} &
